"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BridgeAccounts = exports.BridgeAccountNames = void 0;
var BridgeAccountNames;
(function (BridgeAccountNames) {
    BridgeAccountNames["algorand_asaOwner"] = "algorand_asaOwner";
    BridgeAccountNames["algorand_algoOwner"] = "algorand_algoOwner";
    BridgeAccountNames["algorand_bridgeOwner"] = "algorand_bridgeOwner";
    BridgeAccountNames["algorand_feeReceiver"] = "algorand_feeReceiver";
    BridgeAccountNames["algorand_multisig1"] = "algorand_multisig1";
    BridgeAccountNames["algorand_multisig2"] = "algorand_multisig2";
    BridgeAccountNames["algorand__bridge"] = "algorand__bridge";
    BridgeAccountNames["algorand_asaVault"] = "algorand_asaVault";
    BridgeAccountNames["algorand_algoVault"] = "algorand_algoVault";
    BridgeAccountNames["solana_bridge_program_id"] = "bridge_program_id";
    BridgeAccountNames["solana_vesting_program_id"] = "vesting_program_id";
    BridgeAccountNames["solana_owner_address"] = "owner_address";
})(BridgeAccountNames = exports.BridgeAccountNames || (exports.BridgeAccountNames = {}));
class BridgeAccounts {
    //Load Config
    static loadConfig(config) {
        BridgeAccounts.bridgeAccounts = config.bridgeAccounts;
        BridgeAccounts.bridgeMSigs = config.bridgeMSigs;
        if (BridgeAccounts.bridgeAccounts === undefined)
            throw new Error("Bridge Accounts config not found");
        if (BridgeAccounts.bridgeMSigs === undefined)
            throw new Error("Bridge MSigs config not found");
    }
    ;
    //Get Account Info
    static getAddress(name) {
        const network = name.split("_")[0];
        const accountName = name.split("_")[1];
        const info = BridgeAccounts.getAccountInfo(network, accountName);
        if (info === undefined) {
            //Check msig
            const msigInfo = BridgeAccounts.getMSigInfo(network, accountName);
            if (msigInfo === undefined) {
                throw new Error("Account not found: " + name);
            }
            else {
                return msigInfo.address;
            }
        }
        else {
            return info.address;
        }
    }
    static getAccountInfo(network, name) {
        console.log(`matching: ${name.toLowerCase()} ${network.toLowerCase()}`);
        const accounts = this.bridgeAccounts;
        //accounts.push(...BridgeAccounts.config.local_accounts);
        for (let i = 0; i < accounts.length; i++) {
            const info = accounts[i];
            if (info.network.toLowerCase() === network.toLowerCase() &&
                info.name.toLowerCase() === name.toLowerCase()) {
                console.log(`matched: ${info.name.toLowerCase()} ${info.network.toLowerCase()}`);
                if (info.address === undefined)
                    throw new Error("Account address not specified: " + name);
                return info;
            }
        }
        return undefined;
    }
    static getMSigInfo(network, name) {
        console.log(`matching: ${name.toLowerCase()} ${network.toLowerCase()}`);
        const accounts = this.bridgeMSigs;
        //accounts.push(...BridgeAccounts.config.local_msigs);
        for (let i = 0; i < accounts.length; i++) {
            const info = accounts[i];
            if (info.network.toLowerCase() === network.toLowerCase() &&
                info.name.toLowerCase() === name.toLowerCase()) {
                console.log(`matched: ${info.name.toLowerCase()} ${info.network.toLowerCase()}`);
                if (info.address === undefined)
                    throw new Error("MSig address not specified: " + name);
                return info;
            }
        }
        return undefined;
    }
}
exports.BridgeAccounts = BridgeAccounts;
