"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BridgeTokens = exports.BridgeTokenParamsDefault = exports.BridgeTokenDefault = void 0;
function BridgeTokenDefault() {
    return {
        symbol: "",
        network: "",
        address: undefined,
        decimals: 0,
        params: BridgeTokenParamsDefault(),
    };
}
exports.BridgeTokenDefault = BridgeTokenDefault;
function BridgeTokenParamsDefault() {
    return {
        name: undefined,
        fee_divisor: undefined,
        min_transfer: undefined,
        max_transfer: undefined,
        total_supply: undefined
    };
}
exports.BridgeTokenParamsDefault = BridgeTokenParamsDefault;
class BridgeTokens {
    static loadConfig(config) {
        if (config.tokens === undefined) {
            throw new Error("Tokens config not found");
        }
        else if (this._tokens === undefined) {
            this._tokens = config.tokens;
        }
        else {
            //Parse config tokens and add to list
            config.tokens.forEach(token => {
                //check if token already exists
                const existing = BridgeTokens.get(token.network, token.symbol);
                if (existing !== undefined) {
                    return existing;
                }
            });
        }
    }
    static get(network, symbol) {
        return BridgeTokens._tokens.find(t => {
            if (!t.symbol || !t.network)
                return false;
            return t.network.toLowerCase() === network.toLowerCase() && t.symbol.toLowerCase() === symbol.toLowerCase();
        });
    }
    static add(...args) {
        //Check if already exists
        const existing = BridgeTokens.get(args[0].network, args[0].symbol);
        if (existing !== undefined) {
            BridgeTokens._tokens.push(args[0]);
        }
    }
}
exports.BridgeTokens = BridgeTokens;
